@@ -120,8 +120,8 @@ arch_flags="-arch $arch"
 # but is larger still.
 dmg_format=UDBZ
 
-WX_VERSION=3.0.2
-WX_SHA256=346879dc554f3ab8d6da2704f651ecb504a22e9d31c17ef5449b129ed711585d
+WX_VERSION=3.0.4
+WX_SHA256=96157f988d261b7368e5340afa1a0cad943768f35929c22841f62c25b17bf7f0
 
 PROJ_VERSION=4.9.3
 PROJ_SHA256=6984542fea333488de5c82eea58d699e4aff4b359200a9971537cd7e047185f7
@@ -136,7 +136,7 @@ if [ -z "${WX_CONFIG+set}" ] && [ "$install_wx" != no ] ; then
     prefix=`pwd`/WXINSTALL
     wxtarball=wxWidgets-$WX_VERSION.tar.bz2
     test -f "$wxtarball" || \
-      curl -L -O "http://downloads.sourceforge.net/project/wxwindows/$WX_VERSION/$wxtarball"
+      curl -L -O "https://github.com/wxWidgets/wxWidgets/releases/download/v$WX_VERSION/$wxtarball"
     if echo "$WX_SHA256  $wxtarball" | shasum -a256 -c ; then
       : # OK
     else
@@ -160,6 +160,15 @@ if [ -z "${WX_CONFIG+set}" ] && [ "$install_wx" != no ] ; then
   WX_CONFIG=`pwd`/WXINSTALL/bin/wx-config
 fi
 
+[ -n "${WX_CONFIG}" ] || WX_CONFIG=`which wx-config 2>/dev/null`
+if [ -z "${WX_CONFIG}" ] ; then
+  echo "wx-config not found in PATH."
+  echo
+  echo "If wxWidgets is installed, you can specify its location by setting environment variable WX_CONFIG:"
+  echo
+  echo "WX_CONFIG=/opt/bin/wx-config sh ./buildmacosx.sh"
+  exit 1
+fi
 CC=`$WX_CONFIG --cc`
 CXX=`$WX_CONFIG --cxx`
 
@@ -241,9 +250,7 @@ make install
 #mv Survex/survex Survex/Survex
 
 # Construct the Aven application bundle.
-mkdir -p Survex/Aven.app/Contents/MacOS Survex/Aven.app/Contents/Resources
-cp lib/Info.plist Survex/Aven.app/Contents
-printf APPLAVEN > Survex/Aven.app/Contents/PkgInfo
+make create-aven-app APP_PATH=Survex/Aven.app
 mv Survex/share/doc/survex Survex/Docs
 rmdir Survex/share/doc
 mv Survex/share/survex/images Survex/Aven.app/Contents/Resources/
@@ -257,14 +264,6 @@ cp -p PROJINSTALL/share/proj/epsg PROJINSTALL/share/proj/esri Survex/share/surve
 mkdir Survex/Aven.app/Contents/Resources/proj
 ln Survex/share/survex/proj/* Survex/Aven.app/Contents/Resources/proj
 
-# Create .icns files in the bundle's "Resources" directory.
-for zip in lib/icons/*.iconset.zip ; do
-  unzip -d Survex/Aven.app/Contents/Resources "$zip"
-  i=`echo "$zip"|sed 's!.*/\(.*\)\.zip$!\1!'`
-  iconutil --convert icns "Survex/Aven.app/Contents/Resources/$i"
-  rm -rf "Survex/Aven.app/Contents/Resources/$i"
-done
-
 size=`du -s Survex|sed 's/[^0-9].*//'`
 # Allow 1500 extra sectors for various overheads (1000 wasn't enough).
 sectors=`expr 1500 + "$size"`
