@@ -559,8 +559,8 @@ static const unsigned char fontdata_preloaded[] = {
     132, 132, 132, 132,   0,   0,  72,  72,
      70,  13, 120,   4,   4,  52,  76, 132,
     132, 132, 132, 132,   0,   0,  96,  24,
-     69,  11, 128, 128, 128, 192, 160, 144,
-    136, 136, 136, 240, 128, 128,  70,  13,
-    120,   4,   4,  52,  76, 132, 132, 132,
-    132, 132,   0,   0,  72,  72,
+     70,  12, 128, 128, 184, 196, 132, 132,
+    132, 132, 196, 184, 128, 128, 128,  70,
+     13, 120,   4,   4,  52,  76, 132, 132,
+    132, 132, 132,   0,   0,  72,  72,
 };
