@@ -4,7 +4,7 @@
 //  About box handling for Aven.
 //
 //  Copyright (C) 2001-2003 Mark R. Shinwell.
-//  Copyright (C) 2001,2002,2003,2004,2005,2006,2010,2014,2015 Olly Betts
+//  Copyright (C) 2001,2002,2003,2004,2005,2006,2010,2014,2015,2017 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -153,14 +153,12 @@ AboutDlg::AboutDlg(wxWindow* parent, const wxIcon & app_icon) :
     info += wxT("\nBuilt with ") wxVERSION_STRING
 #endif
 #ifdef __WXGTK__
-# if defined __WXGTK26__
-	wxT(" (GTK+ >= 2.6)\n");
-# elif defined __WXGTK24__
-	wxT(" (GTK+ >= 2.4)\n");
+# if defined __WXGTK3__
+	wxT(" (GTK+ 3)\n");
 # elif defined __WXGTK20__
-	wxT(" (GTK+ >= 2.0)\n");
+	wxT(" (GTK+ 2)\n");
 # elif defined __WXGTK12__
-	wxT(" (GTK+ >= 1.2)\n");
+	wxT(" (GTK+ 1.2)\n");
 # else
 	wxT(" (GTK+ < 1.2)\n");
 # endif
@@ -189,7 +187,7 @@ AboutDlg::AboutDlg(wxWindow* parent, const wxIcon & app_icon) :
 			     wxDefaultSize, wxTE_MULTILINE|wxTE_READONLY),
 	      1, wxLEFT | wxRIGHT | wxEXPAND, 20);
 
-    vert->Add(10, 5, 0, wxALIGN_BOTTOM | wxTOP, 5);
+    vert->Add(10, 5, 0, wxTOP, 5);
 
     wxBoxSizer* bottom = new wxBoxSizer(wxHORIZONTAL);
     bottom->Add(5, 5, 1);
