@@ -64,7 +64,7 @@ public:
     void pages_required();
     int get_effective_show_mask() const {
 	int result = show_mask;
-	if (view != PLAN && view != ELEV) {
+	if (view == tilt) {
 	    result &= ~(XSECT|WALLS|PASG);
 	}
 	return result;
