@@ -1,7 +1,8 @@
 //
 //  aventypes.h
 //
-//  Copyright (C) 2001, Mark R. Shinwell.
+//  Copyright (C) 2001-2002 Mark R. Shinwell.
+//  Copyright (C) 2002,2005 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -15,23 +16,18 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
 #ifndef aventypes_h
 #define aventypes_h
 
-#include "config.h"
-
-#ifdef AVENGL
-#ifdef _WIN32
-#include <windows.h>
-#endif
-#include <GL/glu.h>
-#include <GL/glut.h>
-typedef GLdouble Double;
+#ifdef __APPLE__
+#include <OpenGL/glu.h>
 #else
-typedef double Double;
+#include <GL/glu.h>
 #endif
 
+typedef GLdouble Double;
+
 #endif
