@@ -322,7 +322,7 @@ typedef struct Settings {
    real z[Q_MAC];
    real sc[Q_MAC];
    real units[Q_MAC];
-   reading *ordering;
+   const reading *ordering;
    int begin_lineno; /* 0 means no block started in this file */
    int flags;
    projPJ proj;
