@@ -629,17 +629,22 @@ void GUIControl::OnShowSurveyLegsUpdate(wxUpdateUIEvent& cmd)
 
 void GUIControl::OnHideSplays()
 {
-    m_View->SetSplaysMode(SPLAYS_HIDE);
+    m_View->SetSplaysMode(SHOW_HIDE);
 }
 
-void GUIControl::OnShowSplaysNormal()
+void GUIControl::OnShowSplaysDashed()
 {
-    m_View->SetSplaysMode(SPLAYS_SHOW_NORMAL);
+    m_View->SetSplaysMode(SHOW_DASHED);
 }
 
 void GUIControl::OnShowSplaysFaded()
 {
-    m_View->SetSplaysMode(SPLAYS_SHOW_FADED);
+    m_View->SetSplaysMode(SHOW_FADED);
+}
+
+void GUIControl::OnShowSplaysNormal()
+{
+    m_View->SetSplaysMode(SHOW_NORMAL);
 }
 
 void GUIControl::OnSplaysUpdate(wxUpdateUIEvent& cmd)
@@ -650,19 +655,65 @@ void GUIControl::OnSplaysUpdate(wxUpdateUIEvent& cmd)
 void GUIControl::OnHideSplaysUpdate(wxUpdateUIEvent& cmd)
 {
     cmd.Enable(m_View->HasData() && m_View->HasSplays());
-    cmd.Check(m_View->ShowingSplaysMode() == SPLAYS_HIDE);
+    cmd.Check(m_View->ShowingSplaysMode() == SHOW_HIDE);
 }
 
-void GUIControl::OnShowSplaysNormalUpdate(wxUpdateUIEvent& cmd)
+void GUIControl::OnShowSplaysDashedUpdate(wxUpdateUIEvent& cmd)
 {
     cmd.Enable(m_View->HasData() && m_View->HasSplays());
-    cmd.Check(m_View->ShowingSplaysMode() == SPLAYS_SHOW_NORMAL);
+    cmd.Check(m_View->ShowingSplaysMode() == SHOW_DASHED);
 }
 
 void GUIControl::OnShowSplaysFadedUpdate(wxUpdateUIEvent& cmd)
 {
     cmd.Enable(m_View->HasData() && m_View->HasSplays());
-    cmd.Check(m_View->ShowingSplaysMode() == SPLAYS_SHOW_FADED);
+    cmd.Check(m_View->ShowingSplaysMode() == SHOW_FADED);
+}
+
+void GUIControl::OnShowSplaysNormalUpdate(wxUpdateUIEvent& cmd)
+{
+    cmd.Enable(m_View->HasData() && m_View->HasSplays());
+    cmd.Check(m_View->ShowingSplaysMode() == SHOW_NORMAL);
+}
+
+void GUIControl::OnHideDupes() {
+    m_View->SetDupesMode(SHOW_HIDE);
+}
+
+void GUIControl::OnShowDupesDashed() {
+    m_View->SetDupesMode(SHOW_DASHED);
+}
+
+void GUIControl::OnShowDupesFaded() {
+    m_View->SetDupesMode(SHOW_FADED);
+}
+
+void GUIControl::OnShowDupesNormal() {
+    m_View->SetDupesMode(SHOW_NORMAL);
+}
+
+void GUIControl::OnDupesUpdate(wxUpdateUIEvent& cmd) {
+    cmd.Enable(m_View->HasData() && m_View->HasDupes());
+}
+
+void GUIControl::OnHideDupesUpdate(wxUpdateUIEvent& cmd) {
+    cmd.Enable(m_View->HasData() && m_View->HasDupes());
+    cmd.Check(m_View->ShowingDupesMode() == SHOW_HIDE);
+}
+
+void GUIControl::OnShowDupesDashedUpdate(wxUpdateUIEvent& cmd) {
+    cmd.Enable(m_View->HasData() && m_View->HasDupes());
+    cmd.Check(m_View->ShowingDupesMode() == SHOW_DASHED);
+}
+
+void GUIControl::OnShowDupesFadedUpdate(wxUpdateUIEvent& cmd) {
+    cmd.Enable(m_View->HasData() && m_View->HasDupes());
+    cmd.Check(m_View->ShowingDupesMode() == SHOW_FADED);
+}
+
+void GUIControl::OnShowDupesNormalUpdate(wxUpdateUIEvent& cmd) {
+    cmd.Enable(m_View->HasData() && m_View->HasDupes());
+    cmd.Check(m_View->ShowingDupesMode() == SHOW_NORMAL);
 }
 
 void GUIControl::OnMoveEast()
