@@ -81,8 +81,13 @@ public:
     void OnShowStationNames();
     void OnShowSurveyLegs();
     void OnHideSplays();
-    void OnShowSplaysNormal();
+    void OnShowSplaysDashed();
     void OnShowSplaysFaded();
+    void OnShowSplaysNormal();
+    void OnHideDupes();
+    void OnShowDupesDashed();
+    void OnShowDupesFaded();
+    void OnShowDupesNormal();
     void OnShowSurface();
     void OnMoveEast();
     void OnMoveNorth();
@@ -134,8 +139,14 @@ public:
     void OnShowSurveyLegsUpdate(wxUpdateUIEvent&);
     void OnSplaysUpdate(wxUpdateUIEvent&);
     void OnHideSplaysUpdate(wxUpdateUIEvent&);
-    void OnShowSplaysNormalUpdate(wxUpdateUIEvent&);
+    void OnShowSplaysDashedUpdate(wxUpdateUIEvent&);
     void OnShowSplaysFadedUpdate(wxUpdateUIEvent&);
+    void OnShowSplaysNormalUpdate(wxUpdateUIEvent&);
+    void OnDupesUpdate(wxUpdateUIEvent&);
+    void OnHideDupesUpdate(wxUpdateUIEvent&);
+    void OnShowDupesDashedUpdate(wxUpdateUIEvent&);
+    void OnShowDupesFadedUpdate(wxUpdateUIEvent&);
+    void OnShowDupesNormalUpdate(wxUpdateUIEvent&);
     void OnShowSurfaceUpdate(wxUpdateUIEvent&);
     void OnMoveEastUpdate(wxUpdateUIEvent&);
     void OnMoveNorthUpdate(wxUpdateUIEvent&);
