@@ -569,8 +569,13 @@ BEGIN_EVENT_TABLE(MainFrm, wxFrame)
     EVT_MENU(menu_ORIENT_DEFAULTS, MainFrm::OnDefaults)
     EVT_MENU(menu_VIEW_SHOW_LEGS, MainFrm::OnShowSurveyLegs)
     EVT_MENU(menu_SPLAYS_HIDE, MainFrm::OnHideSplays)
-    EVT_MENU(menu_SPLAYS_SHOW_NORMAL, MainFrm::OnShowSplaysNormal)
+    EVT_MENU(menu_SPLAYS_SHOW_DASHED, MainFrm::OnShowSplaysDashed)
     EVT_MENU(menu_SPLAYS_SHOW_FADED, MainFrm::OnShowSplaysFaded)
+    EVT_MENU(menu_SPLAYS_SHOW_NORMAL, MainFrm::OnShowSplaysNormal)
+    EVT_MENU(menu_DUPES_HIDE, MainFrm::OnHideDupes)
+    EVT_MENU(menu_DUPES_SHOW_DASHED, MainFrm::OnShowDupesDashed)
+    EVT_MENU(menu_DUPES_SHOW_FADED, MainFrm::OnShowDupesFaded)
+    EVT_MENU(menu_DUPES_SHOW_NORMAL, MainFrm::OnShowDupesNormal)
     EVT_MENU(menu_VIEW_SHOW_CROSSES, MainFrm::OnShowCrosses)
     EVT_MENU(menu_VIEW_SHOW_ENTRANCES, MainFrm::OnShowEntrances)
     EVT_MENU(menu_VIEW_SHOW_FIXED_PTS, MainFrm::OnShowFixedPts)
@@ -623,8 +628,14 @@ BEGIN_EVENT_TABLE(MainFrm, wxFrame)
     EVT_UPDATE_UI(menu_VIEW_SHOW_LEGS, MainFrm::OnShowSurveyLegsUpdate)
     EVT_UPDATE_UI(menu_VIEW_SPLAYS, MainFrm::OnSplaysUpdate)
     EVT_UPDATE_UI(menu_SPLAYS_HIDE, MainFrm::OnHideSplaysUpdate)
-    EVT_UPDATE_UI(menu_SPLAYS_SHOW_NORMAL, MainFrm::OnShowSplaysNormalUpdate)
+    EVT_UPDATE_UI(menu_SPLAYS_SHOW_DASHED, MainFrm::OnShowSplaysDashedUpdate)
     EVT_UPDATE_UI(menu_SPLAYS_SHOW_FADED, MainFrm::OnShowSplaysFadedUpdate)
+    EVT_UPDATE_UI(menu_SPLAYS_SHOW_NORMAL, MainFrm::OnShowSplaysNormalUpdate)
+    EVT_UPDATE_UI(menu_VIEW_DUPES, MainFrm::OnDupesUpdate)
+    EVT_UPDATE_UI(menu_DUPES_HIDE, MainFrm::OnHideDupesUpdate)
+    EVT_UPDATE_UI(menu_DUPES_SHOW_DASHED, MainFrm::OnShowDupesDashedUpdate)
+    EVT_UPDATE_UI(menu_DUPES_SHOW_FADED, MainFrm::OnShowDupesFadedUpdate)
+    EVT_UPDATE_UI(menu_DUPES_SHOW_NORMAL, MainFrm::OnShowDupesNormalUpdate)
     EVT_UPDATE_UI(menu_VIEW_SHOW_CROSSES, MainFrm::OnShowCrossesUpdate)
     EVT_UPDATE_UI(menu_VIEW_SHOW_ENTRANCES, MainFrm::OnShowEntrancesUpdate)
     EVT_UPDATE_UI(menu_VIEW_SHOW_FIXED_PTS, MainFrm::OnShowFixedPtsUpdate)
@@ -727,7 +738,8 @@ MainFrm::MainFrm(const wxString& title, const wxPoint& pos, const wxSize& size)
     m_Gfx(NULL), m_Log(NULL),
     m_NumEntrances(0), m_NumFixedPts(0), m_NumExportedPts(0),
     m_NumHighlighted(0),
-    m_HasUndergroundLegs(false), m_HasSplays(false), m_HasSurfaceLegs(false),
+    m_HasUndergroundLegs(false),
+    m_HasSplays(false), m_HasDupes(false), m_HasSurfaceLegs(false),
     m_HasErrorInformation(false), m_IsExtendedElevation(false),
     pending_find(false), fullscreen_showing_menus(false)
 #ifdef PREFDLG
@@ -814,7 +826,10 @@ void MainFrm::CreateMenuBar()
 
     wxMenu* rotmenu = new wxMenu;
     /* TRANSLATORS: "Rotation" menu.  The accelerators must be different within
-     * this group.  Tickable menu item which toggles auto rotation */
+     * this group.  Tickable menu item which toggles auto rotation.
+     * Please don't translate "Space" - that's the shortcut key to use which
+     * wxWidgets needs to parse and it should then handle translating.
+     */
     rotmenu->AppendCheckItem(menu_ROTATION_TOGGLE, wmsg(/*Au&to-Rotate\tSpace*/231));
     rotmenu->AppendSeparator();
     rotmenu->Append(menu_ROTATION_REVERSE, wmsg(/*&Reverse Direction*/234));
@@ -862,18 +877,27 @@ void MainFrm::CreateMenuBar()
     viewmenu->AppendCheckItem(menu_VIEW_SHOW_SURFACE, wmsg(/*&Surface Survey Legs\tCtrl+F*/291));
 
     wxMenu* splaymenu = new wxMenu;
-    /* TRANSLATORS: Item in the "Splay Legs" submenu - if this is selected,
-     * splay legs are not shown. */
+    /* TRANSLATORS: Item in the "Splay Legs" and "Duplicate Legs" submenus - if
+     * this is selected, such legs are not shown. */
     splaymenu->AppendCheckItem(menu_SPLAYS_HIDE, wmsg(/*&Hide*/407));
-    /* TRANSLATORS: Item in the "Splay Legs" submenu - if this is selected,
-     * aven will show splay legs with less bright colours (rather than the
-     * same as other legs "Show" or not shown "Hide"). */
+    /* TRANSLATORS: Item in the "Splay Legs" and "Duplicate Legs" submenus - if
+     * this is selected, aven will show such legs with dashed lines. */
+    splaymenu->AppendCheckItem(menu_SPLAYS_SHOW_DASHED, wmsg(/*&Dashed*/250));
+    /* TRANSLATORS: Item in the "Splay Legs" and "Duplicate Legs" submenus - if
+     * this is selected, aven will show such legs with less bright colours. */
     splaymenu->AppendCheckItem(menu_SPLAYS_SHOW_FADED, wmsg(/*&Fade*/408));
-    /* TRANSLATORS: Item in the "Splay Legs" submenu - if this is selected,
-     * splay legs are shown the same as other legs. */
+    /* TRANSLATORS: Item in the "Splay Legs" and "Duplicate Legs" submenus - if
+     * this is selected, such legs are shown the same as other legs. */
     splaymenu->AppendCheckItem(menu_SPLAYS_SHOW_NORMAL, wmsg(/*&Show*/409));
     viewmenu->Append(menu_VIEW_SPLAYS, wmsg(/*Spla&y Legs*/406), splaymenu);
 
+    wxMenu* dupemenu = new wxMenu;
+    dupemenu->AppendCheckItem(menu_DUPES_HIDE, wmsg(/*&Hide*/407));
+    dupemenu->AppendCheckItem(menu_DUPES_SHOW_DASHED, wmsg(/*&Dashed*/250));
+    dupemenu->AppendCheckItem(menu_DUPES_SHOW_FADED, wmsg(/*&Fade*/408));
+    dupemenu->AppendCheckItem(menu_DUPES_SHOW_NORMAL, wmsg(/*&Show*/409));
+    viewmenu->Append(menu_VIEW_DUPES, wmsg(/*&Duplicate Legs*/251), dupemenu);
+
     viewmenu->AppendSeparator();
     viewmenu->AppendCheckItem(menu_VIEW_SHOW_OVERLAPPING_NAMES, wmsg(/*&Overlapping Names*/273));
 
@@ -892,6 +916,10 @@ void MainFrm::CreateMenuBar()
     viewmenu->AppendCheckItem(menu_VIEW_SHOW_EXPORTED_PTS, wmsg(/*Highlight E&xported Points*/296));
     viewmenu->AppendSeparator();
 #else
+    /* TRANSLATORS: Please don't translate "Escape" - that's the shortcut key
+     * to use which wxWidgets needs to parse and it should then handle
+     * translating.
+     */
     viewmenu-> Append(menu_VIEW_CANCEL_DIST_LINE, wmsg(/*&Cancel Measuring Line\tEscape*/281));
 #endif
     viewmenu->AppendCheckItem(menu_VIEW_PERSPECTIVE, wmsg(/*&Perspective*/237));
@@ -1134,6 +1162,7 @@ bool MainFrm::LoadData(const wxString& file, const wxString & prefix)
     m_NumEntrances = 0;
     m_HasUndergroundLegs = false;
     m_HasSplays = false;
+    m_HasDupes = false;
     m_HasSurfaceLegs = false;
     m_HasErrorInformation = false;
 
@@ -1156,15 +1185,15 @@ bool MainFrm::LoadData(const wxString& file, const wxString & prefix)
     int datemax = -1;
     complete_dateinfo = true;
 
-    traverses.clear();
-    surface_traverses.clear();
+    for (unsigned f = 0; f != sizeof(traverses) / sizeof(traverses[0]); ++f) {
+	traverses[f].clear();
+    }
     tubes.clear();
 
     // Ultimately we probably want different types (subclasses perhaps?) for
     // underground and surface data, so we don't need to store LRUD for surface
     // stuff.
     traverse * current_traverse = NULL;
-    traverse * current_surface_traverse = NULL;
     vector<XSect> * current_tube = NULL;
 
     map<wxString, LabelInfo *> labelmap;
@@ -1173,15 +1202,15 @@ bool MainFrm::LoadData(const wxString& file, const wxString & prefix)
     int result;
     img_point prev_pt = {0,0,0};
     bool current_polyline_is_surface = false;
-    bool current_polyline_is_splay = false;
+    int current_flags = 0;
     bool pending_move = false;
-    // When a traverse is split between surface and underground, we split it
-    // into contiguous traverses of each, but we need to track these so we can
-    // assign the error statistics to all of them.  So we keep counts of how
-    // many surface_traverses and traverses we've generated for the current
-    // traverse.
-    size_t n_traverses = 0;
-    size_t n_surface_traverses = 0;
+    // When legs within a traverse have different surface/splay/duplicate
+    // flags, we split it into contiguous traverses of each flag combination,
+    // but we need to track these so we can assign the error statistics to all
+    // of them.  So we keep counts of how many of each combination we've
+    // generated for the current traverse.
+    size_t n_traverses[8];
+    memset(n_traverses, 0, sizeof(n_traverses));
     do {
 #if 0
 	if (++items % 200 == 0) {
@@ -1195,7 +1224,7 @@ bool MainFrm::LoadData(const wxString& file, const wxString & prefix)
 	result = img_read_item(survey, &pt);
 	switch (result) {
 	    case img_MOVE:
-		n_traverses = n_surface_traverses = 0;
+		memset(n_traverses, 0, sizeof(n_traverses));
 		pending_move = true;
 		prev_pt = pt;
 		break;
@@ -1218,40 +1247,44 @@ bool MainFrm::LoadData(const wxString& file, const wxString & prefix)
 		    complete_dateinfo = false;
 		}
 
-		if (survey->flags & img_FLAG_SPLAY)
-		    m_HasSplays = true;
-		bool is_surface = (survey->flags & img_FLAG_SURFACE);
-		bool is_splay = (survey->flags & img_FLAG_SPLAY);
+		int flags = survey->flags &
+		    (img_FLAG_SURFACE|img_FLAG_SPLAY|img_FLAG_DUPLICATE);
+		bool is_surface = (flags & img_FLAG_SURFACE);
+		bool is_splay = (flags & img_FLAG_SPLAY);
+		bool is_dupe = (flags & img_FLAG_DUPLICATE);
+
 		if (!is_surface) {
 		    if (pt.z < m_DepthMin) m_DepthMin = pt.z;
 		    if (pt.z > depthmax) depthmax = pt.z;
 		}
-		if (pending_move || current_polyline_is_surface != is_surface || current_polyline_is_splay != is_splay) {
+		if (is_splay)
+		    m_HasSplays = true;
+		if (is_dupe)
+		    m_HasDupes = true;
+		if (pending_move ||
+		    current_flags != flags) {
 		    if (!current_polyline_is_surface && current_traverse) {
 			//FixLRUD(*current_traverse);
 		    }
 
+		    ++n_traverses[flags];
 		    // Start new traverse (surface or underground).
 		    if (is_surface) {
 			m_HasSurfaceLegs = true;
-			surface_traverses.push_back(traverse());
-			current_surface_traverse = &surface_traverses.back();
-			++n_surface_traverses;
 		    } else {
 			m_HasUndergroundLegs = true;
-			traverses.push_back(traverse());
-			current_traverse = &traverses.back();
-			current_traverse->isSplay = is_splay;
-			++n_traverses;
 			// The previous point was at a surface->ug transition.
 			if (current_polyline_is_surface) {
 			    if (prev_pt.z < m_DepthMin) m_DepthMin = prev_pt.z;
 			    if (prev_pt.z > depthmax) depthmax = prev_pt.z;
 			}
 		    }
+		    traverses[flags].push_back(traverse());
+		    current_traverse = &traverses[flags].back();
+		    current_traverse->flags = survey->flags;
 
 		    current_polyline_is_surface = is_surface;
-		    current_polyline_is_splay = is_splay;
+		    current_flags = flags;
 
 		    if (pending_move) {
 			// Update survey extents.  We only need to do this if
@@ -1266,18 +1299,10 @@ bool MainFrm::LoadData(const wxString& file, const wxString & prefix)
 			if (prev_pt.z > zmax) zmax = prev_pt.z;
 		    }
 
-		    if (is_surface) {
-			current_surface_traverse->push_back(PointInfo(prev_pt));
-		    } else {
-			current_traverse->push_back(PointInfo(prev_pt));
-		    }
+		    current_traverse->push_back(PointInfo(prev_pt));
 		}
 
-		if (is_surface) {
-		    current_surface_traverse->push_back(PointInfo(pt, date));
-		} else {
-		    current_traverse->push_back(PointInfo(pt, date));
-		}
+		current_traverse->push_back(PointInfo(pt, date));
 
 		prev_pt = pt;
 		pending_move = false;
@@ -1385,28 +1410,20 @@ bool MainFrm::LoadData(const wxString& file, const wxString & prefix)
 		    break;
 		}
 		m_HasErrorInformation = true;
-		list<traverse>::reverse_iterator t;
-		t = surface_traverses.rbegin();
-		while (n_surface_traverses) {
-		    assert(t != surface_traverses.rend());
-		    t->n_legs = survey->n_legs;
-		    t->length = survey->length;
-		    t->E = survey->E;
-		    t->H = survey->H;
-		    t->V = survey->V;
-		    --n_surface_traverses;
-		    ++t;
-		}
-		t = traverses.rbegin();
-		while (n_traverses) {
-		    assert(t != traverses.rend());
-		    t->n_legs = survey->n_legs;
-		    t->length = survey->length;
-		    t->E = survey->E;
-		    t->H = survey->H;
-		    t->V = survey->V;
-		    --n_traverses;
-		    ++t;
+		for (size_t f = 0; f != sizeof(traverses) / sizeof(traverses[0]); ++f) {
+		    list<traverse>::reverse_iterator t = traverses[f].rbegin();
+		    size_t n = n_traverses[f];
+		    n_traverses[f] = 0;
+		    while (n) {
+			assert(t != traverses[f].rend());
+			t->n_legs = survey->n_legs;
+			t->length = survey->length;
+			t->E = survey->E;
+			t->H = survey->H;
+			t->V = survey->V;
+			--n;
+			++t;
+		    }
 		}
 		break;
 	    }
@@ -1478,7 +1495,14 @@ bool MainFrm::LoadData(const wxString& file, const wxString & prefix)
 	return false;
     }
 
-    if (traverses.empty() && surface_traverses.empty()) {
+    if (traverses[0].empty() &&
+	traverses[1].empty() &&
+	traverses[2].empty() &&
+	traverses[3].empty() &&
+	traverses[4].empty() &&
+	traverses[5].empty() &&
+	traverses[6].empty() &&
+	traverses[7].empty()) {
 	// No legs, so get survey extents from stations
 	list<LabelInfo*>::const_iterator i;
 	for (i = m_Labels.begin(); i != m_Labels.end(); ++i) {
@@ -1751,26 +1775,17 @@ void MainFrm::CentreDataset(const Vector3 & vmin)
 
     m_Offsets = vmin + (m_Ext * 0.5);
 
-    list<traverse>::iterator t = traverses.begin();
-    while (t != traverses.end()) {
-	assert(t->size() > 1);
-	vector<PointInfo>::iterator pos = t->begin();
-	while (pos != t->end()) {
-	    Point & point = *pos++;
-	    point -= m_Offsets;
+    for (unsigned f = 0; f != sizeof(traverses) / sizeof(traverses[0]); ++f) {
+	list<traverse>::iterator t = traverses[f].begin();
+	while (t != traverses[f].end()) {
+	    assert(t->size() > 1);
+	    vector<PointInfo>::iterator pos = t->begin();
+	    while (pos != t->end()) {
+		Point & point = *pos++;
+		point -= m_Offsets;
+	    }
+	    ++t;
 	}
-	++t;
-    }
-
-    t = surface_traverses.begin();
-    while (t != surface_traverses.end()) {
-	assert(t->size() > 1);
-	vector<PointInfo>::iterator pos = t->begin();
-	while (pos != t->end()) {
-	    Point & point = *pos++;
-	    point -= m_Offsets;
-	}
-	++t;
     }
 
     list<vector<XSect> >::iterator i = tubes.begin();
@@ -2273,21 +2288,15 @@ void MainFrm::SetCoords(Double x, Double y, const LabelInfo * there)
 
 	wxString from_str;
 	/* TRANSLATORS: Used in Aven:
-	 * From <stationname>
-	 * H: 123.45m V: 234.56m
-	 * Dist: 456.78m  Brg: 200 */
+	 * From <stationname>: H 12.24m, Brg 234.5°
+	 */
 	from_str.Printf(wmsg(/*From %s*/339), there->name_or_anon().c_str());
 	int brg_unit;
 	if (m_Gfx->GetDegrees()) {
 	    brg_unit = /*°*/344;
 	} else {
 	    brg *= 400.0 / 360.0;
-	    /* TRANSLATORS: alternative angle units (400 grad = 360 degrees =
-	     * full circle).  Try to make this as short as sensibly possible.
-	     *
-	     * E.g. in Italian and Spanish we use "g.cent." rather than
-	     * "gradi quattrocentesimali"/"grados centesimales" */
-	    brg_unit = /*grad*/345;
+	    brg_unit = /*ᵍ*/345;
 	}
 
 	int units;
@@ -2299,9 +2308,9 @@ void MainFrm::SetCoords(Double x, Double y, const LabelInfo * there)
 	}
 	/* TRANSLATORS: "H" is short for "Horizontal", "Brg" for "Bearing" (as
 	 * in Compass bearing) */
-	t.Printf(wmsg(/*%s: H %.2f%s, Brg %03d%s*/374),
+	t.Printf(wmsg(/*%s: H %.2f%s, Brg %03.1f%s*/374),
 		 from_str.c_str(), dh, wmsg(units).c_str(),
-		 int(brg), wmsg(brg_unit).c_str());
+		 brg, wmsg(brg_unit).c_str());
     }
 
     UpdateStatusBar();
@@ -2387,6 +2396,8 @@ void MainFrm::ShowInfo(const LabelInfo *here, const LabelInfo *there)
 	Double brg = deg(atan2(delta.GetX(), delta.GetY()));
 	if (brg < 0) brg += 360;
 
+	Double grd = deg(atan2(delta.GetZ(), d_horiz));
+
 	wxString from_str;
 	from_str.Printf(wmsg(/*From %s*/339), there->name_or_anon().c_str());
 
@@ -2408,14 +2419,44 @@ void MainFrm::ShowInfo(const LabelInfo *here, const LabelInfo *there)
 	    brg_unit = /*°*/344;
 	} else {
 	    brg *= 400.0 / 360.0;
-	    brg_unit = /*grad*/345;
+	    brg_unit = /*ᵍ*/345;
 	}
+	int grd_unit;
+	wxString grd_str;
+	if (m_Gfx->GetPercent()) {
+	    if (grd > 89.99) {
+		grd = 1000000;
+	    } else if (grd < -89.99) {
+		grd = -1000000;
+	    } else {
+		grd = int(100 * tan(rad(grd)));
+	    }
+	    if (grd > 99999 || grd < -99999) {
+		grd_str = grd > 0 ? wxT("+") : wxT("-");
+		/* TRANSLATORS: infinity symbol - used for the percentage gradient on
+		 * vertical angles. */
+		grd_str += wmsg(/*∞*/431);
+	    }
+	    grd_unit = /*%*/96;
+	} else if (m_Gfx->GetDegrees()) {
+	    grd_unit = /*°*/344;
+	} else {
+	    grd *= 400.0 / 360.0;
+	    grd_unit = /*ᵍ*/345;
+	}
+	if (grd_str.empty()) {
+	    grd_str.Printf(wxT("%+02.1f%s"), grd, wmsg(grd_unit).c_str());
+	}
+
 	wxString & d = dist_text;
 	/* TRANSLATORS: "Dist" is short for "Distance", "Brg" for "Bearing" (as
-	 * in Compass bearing) */
-	d.Printf(wmsg(/*%s: %s, Dist %.2f%s, Brg %03d%s*/341),
+	 * in Compass bearing) and "Grd" for "Gradient" (the slope angle
+	 * measured by the clino) */
+	d.Printf(wmsg(/*%s: %s, Dist %.2f%s, Brg %03.1f%s, Grd %s*/341),
 		 from_str.c_str(), hv_str.c_str(),
-		 dr, len_unit.c_str(), int(brg), wmsg(brg_unit).c_str());
+		 dr, len_unit.c_str(),
+		 brg, wmsg(brg_unit).c_str(),
+		 grd_str.c_str());
     } else {
 	dist_text = wxString();
 	m_Gfx->SetThere();
