@@ -1,6 +1,6 @@
 /* message.c
  * Fairly general purpose message and error routines
- * Copyright (C) 1993-2003,2004,2005,2006,2007,2010,2011,2012,2014,2015,2016 Olly Betts
+ * Copyright (C) 1993-2003,2004,2005,2006,2007,2010,2011,2012,2014,2015,2016,2017 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -888,10 +888,13 @@ msg_appname(void)
    return appname_copy;
 }
 
-void
-msg_init(char * const *argv)
+int
+msg_init_(char * const *argv)
 {
    char *p;
+#if OS_UNIX_MACOSX
+   int msg_macosx_relocatable = 0;
+#endif
    SVX_ASSERT(argv);
 
    /* Point to argv[0] itself so we report a more helpful error if the
@@ -918,16 +921,7 @@ msg_init(char * const *argv)
    }
    if (argv[0]) {
       exe_pth = path_from_fnm(argv[0]);
-#ifdef MACOSX_BUNDLE
-      /* If we're being built into a bundle, always look relative to
-       * the path to the binary. */
-#ifdef AVEN
-      /* Aven is packaged as an application, so we must look inside there. */
-      pth_cfg_files = use_path(exe_pth, "../Resources");
-#else
-      pth_cfg_files = use_path(exe_pth, "share/survex");
-#endif
-#elif OS_UNIX && defined DATADIR && defined PACKAGE
+#if OS_UNIX && defined DATADIR && defined PACKAGE
       bool free_pth = fFalse;
       char *pth = getenv("srcdir");
       if (!pth || !pth[0]) {
@@ -937,20 +931,25 @@ msg_init(char * const *argv)
       if (pth[0]) {
 	 struct stat buf;
 #if OS_UNIX_MACOSX
+# ifndef AVEN
 	 /* On MacOS X the programs may be installed anywhere, with the
 	  * share directory and the binaries in the same directory. */
 	 p = use_path(pth, "share/survex/en.msg");
 	 if (lstat(p, &buf) == 0 && S_ISREG(buf.st_mode)) {
 	    pth_cfg_files = use_path(pth, "share/survex");
+	    msg_macosx_relocatable = 1;
 	    goto macosx_got_msg;
 	 }
 	 osfree(p);
-	 /* The cavern which aven runs is a hardlinked copy alongside
-	  * the aven binary.
+# endif
+	 /* In the diskimage package, this case is used for aven, and for
+	  * the hardlinked copies of cavern and extend alongside the aven
+	  * binary, which are the ones which aven runs.
 	  */
 	 p = use_path(pth, "../Resources/en.msg");
 	 if (lstat(p, &buf) == 0 && S_ISREG(buf.st_mode)) {
 	    pth_cfg_files = use_path(pth, "../Resources");
+	    msg_macosx_relocatable = 1;
 	    goto macosx_got_msg;
 	 }
 	 osfree(p);
@@ -1149,11 +1148,18 @@ macosx_got_msg:
 #endif
 
    select_charset(default_charset());
+
+   /* Return 1 if this is a relocatable install, 0 otherwise. */
+#if OS_UNIX_MACOSX
+   return msg_macosx_relocatable;
+#else
+   return OS_WIN32;
+#endif
 }
 
 #if OS_WIN32 || OS_UNIX_MACOSX
 const char *
-msg_proj_finder(const char * file)
+msg_proj_finder_(const char * file)
 {
     static char * r = NULL;
     static int r_len = 0;
@@ -1165,6 +1171,20 @@ msg_proj_finder(const char * file)
 }
 #endif
 
+#ifndef AVEN
+/* Return message if messages available, else a fallback value. */
+static const char *
+msg_opt(int en, const char * fallback)
+{
+   /* NB can't use SVX_ASSERT here! */
+   if (!msg_array || en <= 0 || en >= num_msgs) {
+      return fallback;
+   }
+
+   return msg_array[en];
+}
+#endif
+
 const char *
 msg(int en)
 {
@@ -1217,11 +1237,11 @@ v_report(int severity, const char *fnm, int line, int col, int en, va_list ap)
    if (severity == 0) {
       /* TRANSLATORS: Indicates a warning message e.g.:
        * "spoon.svx:12: warning: *prefix is deprecated" */
-      level = msg(/*warning*/4);
+      level = msg_opt(/*warning*/4, "warning");
    } else {
       /* TRANSLATORS: Indicates an error message e.g.:
        * "spoon.svx:13:4: error: Field may not be omitted" */
-      level = msg(/*error*/93);
+      level = msg_opt(/*error*/93, "error");
    }
    fputs(level, STDERR);
    fputs(": ", STDERR);
