@@ -1,7 +1,7 @@
 /* netskel.c
  * Survex network reduction - remove trailing traverses and concatenate
  * traverses between junctions
- * Copyright (C) 1991-2004,2005,2006,2010,2011,2012,2013,2014 Olly Betts
+ * Copyright (C) 1991-2004,2005,2006,2010,2011,2012,2013,2014,2015 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -86,6 +86,9 @@ solve_network(void /*node *stnlist*/)
    static int first_solve = 1;
    node *stn;
 
+   /* We can't average across solving to fix positions. */
+   clear_last_leg();
+
    if (stnlist == NULL) {
       if (first_solve) fatalerror(/*No survey data*/43);
       /* We've had a *solve followed by another *solve (or the implicit
@@ -172,7 +175,7 @@ remove_trailing_travs(void)
     * (although toporobot actually uses this term to mean something more
     * specific).  Feel free to follow this lead if you can't think of a better
     * term - these messages mostly indicate how processing is progressing.
-    * 
+    *
     * A trailing traverse is a dead end back to a junction. */
    out_current_action(msg(/*Removing trailing traverses*/125));
    FOR_EACH_STN(stn, stnlist) {
@@ -774,7 +777,7 @@ replace_trailing_travs(void)
     * (although toporobot actually uses this term to mean something more
     * specific).  Feel free to follow this lead if you can't think of a better
     * term - these messages mostly indicate how processing is progressing.
-    * 
+    *
     * A trailing traverse is a dead end back to a junction. */
    out_current_action(msg(/*Calculating trailing traverses*/128));
 
