@@ -1,6 +1,6 @@
 /* printing.cc */
 /* Aven printing code */
-/* Copyright (C) 1993-2003,2004,2005,2006,2010,2011,2012,2013,2014,2015,2016 Olly Betts
+/* Copyright (C) 1993-2003,2004,2005,2006,2010,2011,2012,2013,2014,2015,2016,2017 Olly Betts
  * Copyright (C) 2001,2004 Philip Underwood
  *
  * This program is free software; you can redistribute it and/or modify
@@ -442,8 +442,8 @@ svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
 	}
 	m_format->SetSelection(current_format);
 	wxBoxSizer* formatbox = new wxBoxSizer(wxHORIZONTAL);
-	formatbox->Add(label, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5);
-	formatbox->Add(m_format, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5);
+	formatbox->Add(label, 0, wxALIGN_CENTRE_VERTICAL|wxALL, 5);
+	formatbox->Add(m_format, 0, wxALIGN_CENTRE_VERTICAL|wxALL, 5);
 
 	v1->Add(formatbox, 0, wxALIGN_LEFT|wxALL, 0);
     }
@@ -473,8 +473,8 @@ svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
     m_scale = new wxComboBox(this, svx_SCALE, default_scale, wxDefaultPosition,
 			     wxDefaultSize, n_scales, scale_list);
     m_scalebox = new wxBoxSizer(wxHORIZONTAL);
-    m_scalebox->Add(label, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5);
-    m_scalebox->Add(m_scale, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5);
+    m_scalebox->Add(label, 0, wxALIGN_CENTRE_VERTICAL|wxALL, 5);
+    m_scalebox->Add(m_scale, 0, wxALIGN_CENTRE_VERTICAL|wxALL, 5);
 
     m_viewbox->Add(m_scalebox, 0, wxALIGN_LEFT|wxALL, 0);
 
@@ -496,20 +496,21 @@ svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
 	wxFlexGridSizer* anglebox = new wxFlexGridSizer(2);
 	wxStaticText * brg_label, * tilt_label;
 	brg_label = new wxStaticText(this, -1, wmsg(/*Bearing*/259));
-	anglebox->Add(brg_label, 0, wxALIGN_CENTER_VERTICAL|wxALIGN_LEFT|wxALL, 5);
+	anglebox->Add(brg_label, 0, wxALIGN_CENTRE_VERTICAL|wxALIGN_LEFT|wxALL, 5);
 	// wSP_WRAP means that you can scroll past 360 to 0, and vice versa.
 	m_bearing = new wxSpinCtrlDouble(this, svx_BEARING, wxEmptyString,
-		wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS|wxSP_WRAP);
+		wxDefaultPosition, wxDefaultSize,
+		wxSP_ARROW_KEYS|wxALIGN_RIGHT|wxSP_WRAP);
 	m_bearing->SetRange(0.0, 360.0);
 	m_bearing->SetDigits(ANGLE_DP);
-	anglebox->Add(m_bearing, 0, wxALIGN_CENTER|wxALL, 5);
+	anglebox->Add(m_bearing, 0, wxALIGN_CENTRE|wxALL, 5);
 	/* TRANSLATORS: Used in the print dialog: */
 	tilt_label = new wxStaticText(this, -1, wmsg(/*Tilt angle*/263));
-	anglebox->Add(tilt_label, 0, wxALIGN_CENTER_VERTICAL|wxALIGN_LEFT|wxALL, 5);
+	anglebox->Add(tilt_label, 0, wxALIGN_CENTRE_VERTICAL|wxALIGN_LEFT|wxALL, 5);
 	m_tilt = new wxSpinCtrlDouble(this, svx_TILT);
 	m_tilt->SetRange(-90.0, 90.0);
 	m_tilt->SetDigits(ANGLE_DP);
-	anglebox->Add(m_tilt, 0, wxALIGN_CENTER|wxALL, 5);
+	anglebox->Add(m_tilt, 0, wxALIGN_CENTRE|wxALL, 5);
 
 	m_viewbox->Add(anglebox, 0, wxALIGN_LEFT|wxALL, 0);
 
@@ -632,7 +633,7 @@ svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
 	wxTextCtrl * proj_edit = new wxTextCtrl(this, svx_PROJ, m_layout.cs_proj,
 						wxDefaultPosition, wxDefaultSize,
 						style);
-	h2->Add(proj_edit, 1, wxALL|wxEXPAND|wxALIGN_CENTRE_VERTICAL, 5);
+	h2->Add(proj_edit, 1, wxALL|wxEXPAND, 5);
 	v1->Add(h2, 0, wxALIGN_LEFT|wxEXPAND, 5);
     }
 
@@ -646,11 +647,11 @@ svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
 
     wxButton * but;
     but = new wxButton(this, wxID_CANCEL);
-    h3->Add(but, 0, wxALIGN_RIGHT|wxALL, 5);
+    h3->Add(but, 0, wxALL, 5);
     if (printing) {
 #ifdef AVEN_PRINT_PREVIEW
 	but = new wxButton(this, wxID_PREVIEW);
-	h3->Add(but, 0, wxALIGN_RIGHT|wxALL, 5);
+	h3->Add(but, 0, wxALL, 5);
 	but = new wxButton(this, wxID_PRINT);
 #else
 	but = new wxButton(this, wxID_PRINT, wmsg(/*&Print...*/400));
@@ -661,7 +662,7 @@ svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
 	but = new wxButton(this, svx_EXPORT, wmsg(/*&Export...*/230));
     }
     but->SetDefault();
-    h3->Add(but, 0, wxALIGN_RIGHT|wxALL, 5);
+    h3->Add(but, 0, wxALL, 5);
     v1->Add(h3, 0, wxALIGN_RIGHT|wxALL, 5);
 
     SetAutoLayout(true);
@@ -1748,10 +1749,12 @@ svxPrintout::OnBeginPrinting() {
     m_layout->scX = 1;
     m_layout->scY = 1;
 
-    font_labels = new wxFont(fontsize_labels, wxDEFAULT, wxNORMAL, wxNORMAL,
+    font_labels = new wxFont(fontsize_labels, wxFONTFAMILY_DEFAULT,
+			     wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL,
 			     false, wxString(fontname_labels, wxConvUTF8),
 			     wxFONTENCODING_ISO8859_1);
-    font_default = new wxFont(fontsize, wxDEFAULT, wxNORMAL, wxNORMAL,
+    font_default = new wxFont(fontsize, wxFONTFAMILY_DEFAULT,
+			      wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL,
 			      false, wxString(fontname, wxConvUTF8),
 			      wxFONTENCODING_ISO8859_1);
 }
@@ -2037,7 +2040,8 @@ svxPrintout::NewPage(int pg, int pagesX, int pagesY)
     const wxChar * footer_sep = wxT("    ");
     int fontsize_footer = fontsize_labels;
     wxFont * font_footer;
-    font_footer = new wxFont(fontsize_footer, wxDEFAULT, wxNORMAL, wxNORMAL,
+    font_footer = new wxFont(fontsize_footer, wxFONTFAMILY_DEFAULT,
+			     wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL,
 			     false, wxString(fontname_labels, wxConvUTF8),
 			     wxFONTENCODING_UTF8);
     font_footer->Scale(font_scaling_x);
